@@ -30,7 +30,7 @@ int main(int argc, char **argv)
         value++;
     });
     timer->start();
-
-    // TODO
-    return app.exec();
+    const int returnValue = app.exec();
+    delete timer;
+    return returnValue;
 }
