@@ -127,6 +127,7 @@ void CalendarBasePrivate::internalInsert(const Akonadi::Item &item)
     }
 
     incidence->setCustomProperty("VOLATILE", "AKONADI-ID", QString::number(item.id()));
+    incidence->setCustomProperty("VOLATILE", "COLLECTION-ID", QString::number(item.storageCollectionId()));
     // Must be the last one due to re-entrancy
     const bool result = q->MemoryCalendar::addIncidence(incidence);
     if (!result) {
@@ -214,7 +215,7 @@ void CalendarBasePrivate::internalRemove(const Akonadi::Item &item)
 }
 
 void CalendarBasePrivate::slotDeleteFinished(int changeId,
-                                             const QVector<Akonadi::Item::Id> &itemIds,
+                                             const QList<Akonadi::Item::Id> &itemIds,
                                              IncidenceChanger::ResultCode resultCode,
                                              const QString &errorMessage)
 {
@@ -379,9 +380,6 @@ CalendarBase::CalendarBase(QObject *parent)
     , d_ptr(new CalendarBasePrivate(this))
 {
     setParent(parent);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    setDeletionTracking(false);
-#endif
 }
 
 CalendarBase::CalendarBase(CalendarBasePrivate *const dd, QObject *parent)
@@ -389,9 +387,6 @@ CalendarBase::CalendarBase(CalendarBasePrivate *const dd, QObject *parent)
     , d_ptr(dd)
 {
     setParent(parent);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    setDeletionTracking(false);
-#endif
 }
 
 CalendarBase::~CalendarBase() = default;
