@@ -9,6 +9,8 @@
 #include "akonadi-calendar_export.h"
 #include "calendarbase.h"
 
+class QAbstractItemModel;
+
 namespace Akonadi
 {
 class Collection;
@@ -24,19 +26,19 @@ public:
     using Ptr = QSharedPointer<CollectionCalendar>;
 
     explicit CollectionCalendar(const Akonadi::Collection &col, QObject *parent = nullptr);
-    CollectionCalendar(Akonadi::EntityTreeModel *model, const Akonadi::Collection &col, QObject *parent = nullptr);
+    CollectionCalendar(QAbstractItemModel *model, const Akonadi::Collection &col, QObject *parent = nullptr);
     ~CollectionCalendar() override;
 
-    Akonadi::Collection collection() const;
+    [[nodiscard]] Akonadi::Collection collection() const;
     void setCollection(const Akonadi::Collection &c);
 
-    Akonadi::EntityTreeModel *model() const;
+    [[nodiscard]] Akonadi::EntityTreeModel *model() const;
 
     bool addEvent(const KCalendarCore::Event::Ptr &event) override;
     bool addTodo(const KCalendarCore::Todo::Ptr &todo) override;
     bool addJournal(const KCalendarCore::Journal::Ptr &journal) override;
 
-    bool hasRight(Akonadi::Collection::Right right) const;
+    [[nodiscard]] bool hasRight(Akonadi::Collection::Right right) const;
 
 Q_SIGNALS:
     /**
@@ -48,4 +50,4 @@ private:
     Q_DECLARE_PRIVATE(CollectionCalendar)
 };
 
-} // namespace Akonadi
\ No newline at end of file
+} // namespace Akonadi
