@@ -753,7 +753,8 @@ bool MailClient::determineWhetherToSign(bool doSignCompletely,
             "You have requested to sign this message, "
             "but no valid signing keys have been configured "
             "for this identity.");
-        if (dialogDelegate->warningContinueCancel(msg, i18n("Send Unsigned?"), KGuiItem(i18nc("@action:button", "Send &Unsigned"))) == KMessageBox::Cancel) {
+        if (dialogDelegate->warningContinueCancel(msg, i18nc("@title:window", "Send Unsigned?"), KGuiItem(i18nc("@action:button", "Send &Unsigned")))
+            == KMessageBox::Cancel) {
             result = false;
             return false;
         } else {
@@ -766,16 +767,16 @@ bool MailClient::determineWhetherToSign(bool doSignCompletely,
     if (!sign || !doSignCompletely) {
         if (cryptoWarningUnsigned(identity)) {
             const QString msg = sign && !doSignCompletely ? i18n(
-                                    "Some parts of this message will not be signed.\n"
-                                    "Sending only partially signed messages might violate site policy.\n"
-                                    "Sign all parts instead?") // oh, I hate this...
+                                                                "Some parts of this message will not be signed.\n"
+                                                                "Sending only partially signed messages might violate site policy.\n"
+                                                                "Sign all parts instead?") // oh, I hate this...
                                                           : i18n(
-                                                              "This message will not be signed.\n"
-                                                              "Sending unsigned message might violate site policy.\n"
-                                                              "Sign message instead?"); // oh, I hate this...
+                                                                "This message will not be signed.\n"
+                                                                "Sending unsigned message might violate site policy.\n"
+                                                                "Sign message instead?"); // oh, I hate this...
             const QString buttonText = sign && !doSignCompletely ? i18n("&Sign All Parts") : i18n("&Sign");
             switch (dialogDelegate->warningTwoActionsCancel(msg,
-                                                            i18n("Unsigned-Message Warning"),
+                                                            i18nc("@title:window", "Unsigned-Message Warning"),
                                                             KGuiItem(buttonText),
                                                             KGuiItem(i18nc("@action:button", "Send &As Is")))) {
             case ITIPHandlerDialogDelegate::CancelAction:
@@ -830,15 +831,15 @@ bool MailClient::determineWhetherToEncrypt(bool doEncryptCompletely,
     case Kleo::Ask: {
         // the user wants to be asked or has to be asked
         const QString msg = opportunistic ? i18n(
-                                "Valid trusted encryption keys were found for all recipients.\n"
-                                "Encrypt this message?")
+                                                "Valid trusted encryption keys were found for all recipients.\n"
+                                                "Encrypt this message?")
                                           : i18n(
-                                              "Examination of the recipient's encryption preferences "
-                                              "yielded that you be asked whether or not to encrypt "
-                                              "this message.\n"
-                                              "Encrypt this message?");
+                                                "Examination of the recipient's encryption preferences "
+                                                "yielded that you be asked whether or not to encrypt "
+                                                "this message.\n"
+                                                "Encrypt this message?");
         switch (dialogDelegate->warningTwoActionsCancel(msg,
-                                                        i18n("Encrypt Message?"),
+                                                        i18nc("@title:window", "Encrypt Message?"),
                                                         KGuiItem(signSomething ? i18n("Sign && &Encrypt") : i18n("&Encrypt")),
                                                         KGuiItem(signSomething ? i18n("&Sign Only") : i18n("&Send As-Is")))) {
         case ITIPHandlerDialogDelegate::CancelAction:
@@ -903,15 +904,15 @@ bool MailClient::determineWhetherToEncrypt(bool doEncryptCompletely,
     if (!encrypt || !doEncryptCompletely) {
         if (cryptoWarningUnencrypted(identity)) {
             const QString msg = !doEncryptCompletely ? i18n(
-                                    "Some parts of this message will not be encrypted.\n"
-                                    "Sending only partially encrypted messages might violate "
-                                    "site policy and/or leak sensitive information.\n"
-                                    "Encrypt all parts instead?") // oh, I hate this...
+                                                           "Some parts of this message will not be encrypted.\n"
+                                                           "Sending only partially encrypted messages might violate "
+                                                           "site policy and/or leak sensitive information.\n"
+                                                           "Encrypt all parts instead?") // oh, I hate this...
                                                      : i18n(
-                                                         "This message will not be encrypted.\n"
-                                                         "Sending unencrypted messages might violate site policy and/or "
-                                                         "leak sensitive information.\n"
-                                                         "Encrypt messages instead?"); // oh, I hate this...
+                                                           "This message will not be encrypted.\n"
+                                                           "Sending unencrypted messages might violate site policy and/or "
+                                                           "leak sensitive information.\n"
+                                                           "Encrypt messages instead?"); // oh, I hate this...
             const QString buttonText = !doEncryptCompletely ? i18n("&Encrypt All Parts") : i18n("&Encrypt");
             switch (dialogDelegate->warningTwoActionsCancel(msg,
                                                             i18n("Unencrypted Message Warning"),
